pub struct CourseStudentsProgressStructure {
pub chapter_locking_enabled: bool,
pub chapters: Vec<DatabaseChapter>,
pub chapter_availability: Vec<ChapterAvailability>,
}Expand description
Course-level progress structure for the Progress tab. Does not depend on which students are on the current page, so it is fetched once and cached per course (not per identity page).
Fields
chapter_locking_enabled: boolchapters: Vec<DatabaseChapter>chapter_availability: Vec<ChapterAvailability>Trait Implementations
Sourceimpl Clone for CourseStudentsProgressStructure
impl Clone for CourseStudentsProgressStructure
Sourcefn clone(&self) -> CourseStudentsProgressStructure
fn clone(&self) -> CourseStudentsProgressStructure
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CourseStudentsProgressStructure
impl ComposeSchema for CourseStudentsProgressStructure
Sourceimpl<'de> Deserialize<'de> for CourseStudentsProgressStructure
impl<'de> Deserialize<'de> for CourseStudentsProgressStructure
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CourseStudentsProgressStructure
impl PartialEq for CourseStudentsProgressStructure
Sourcefn eq(&self, other: &CourseStudentsProgressStructure) -> bool
fn eq(&self, other: &CourseStudentsProgressStructure) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ToSchema for CourseStudentsProgressStructure
impl ToSchema for CourseStudentsProgressStructure
impl StructuralPartialEq for CourseStudentsProgressStructure