pub struct StudentsListPage {
pub data: Vec<CourseStudentListRow>,
pub total_pages: u32,
}Expand description
A page of the student identity list plus the total number of pages for the current filters.
Fields
data: Vec<CourseStudentListRow>total_pages: u32Trait Implementations
Sourceimpl Clone for StudentsListPage
impl Clone for StudentsListPage
Sourcefn clone(&self) -> StudentsListPage
fn clone(&self) -> StudentsListPage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for StudentsListPage
impl ComposeSchema for StudentsListPage
Sourceimpl<'de> Deserialize<'de> for StudentsListPage
impl<'de> Deserialize<'de> for StudentsListPage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for StudentsListPage
impl PartialEq for StudentsListPage
Sourceimpl Serialize for StudentsListPage
impl Serialize for StudentsListPage
Sourceimpl ToSchema for StudentsListPage
impl ToSchema for StudentsListPage
impl StructuralPartialEq for StudentsListPage